@@ -78,6 +78,8 @@ impl Session {
                 if buf[0] != msg::NEWKEYS {
                     return Err(Error::Kex.into());
                 }
+                self.common.write_buffer.bytes = 0;
+                enc.last_rekey = std::time::Instant::now();
                 // Ok, NEWKEYS received, now encrypted.
                 self.common.newkeys(newkeys);
                 return Ok(self);
